( cd usr/lib ; rm -rf libt1.so )
( cd usr/lib ; ln -sf libt1.so.1.3.1 libt1.so )
( cd usr/lib ; rm -rf libt1.so.1 )
( cd usr/lib ; ln -sf libt1.so.1.3.1 libt1.so.1 )
( cd usr/lib ; rm -rf libt1x.so )
( cd usr/lib ; ln -sf libt1x.so.1.3.1 libt1x.so )
( cd usr/lib ; rm -rf libt1x.so.1 )
( cd usr/lib ; ln -sf libt1x.so.1.3.1 libt1x.so.1 )
